# Topsis-Archit-101903054
It takes the dataset and calculates the TOPSIS and assign the topsis score and rank!

## Installation
```pip install Topsis-Archit-101903054```

## How to use it?
Open terminal Write:
```Topsis <inputFilename.csv> <"Weights"> <"Impacts"> <outputFilename.csv>```

## License

© 2022 Archit Kapoor

This repository is licensed under the MIT license. See LICENSE for details.